VirtAddr

Struct VirtAddr 

#[repr(transparent)]
pub struct VirtAddr(u64);
A type representing virtual addresses in the CPU’s virtual address space

Tuple Fields

0: u64

Implementations

Source

impl VirtAddr

pub const fn new(addr: u64) -> Self

Creates a new VirtAddr from a raw u64 address

pub const fn null() -> Self

Creates a new VirtAddr which points to 0

pub fn from_ptr<T>(ptr: *const T) -> Self

Creates a new VirtAddr from a *const T or *mut T pointer

pub fn from_phys(phys: PhysAddr) -> Self

Creates a new VirtAddr from a physical address

pub fn as_u64(self) -> u64

Returns the address as a u64

pub fn as_usize(self) -> usize

Returns the address as a usize

pub fn as_ptr<T>(self) -> *const T

Returns the address as a *const T pointer

pub fn as_mut_ptr<T>(self) -> *mut T

Returns the address as a *mut T pointer

pub fn align_up(self, align: u64) -> Self

Returns a new address aligned to the next larger address which is aligned to align

Panics

In debug builds if align is not a power of two

pub fn align_down(self, align: u64) -> Self

Returns a new address aligned to the next smaller address which is aligned to align

Panics

In debug builds if align is not a power of two

pub fn is_aligned(self, align: u64) -> bool

Check whether the address is aligned to align

Source

impl VirtAddr

pub fn as_x86_64(self) -> VirtAddr

Returns a [x86_64::VirtAddr] with the same address value

pub fn p1_index(self) -> PageTableIndex

Returns the index into the P1 page table (PT) for this virtual address, in range 0..512

pub fn p2_index(self) -> PageTableIndex

Returns the index into the P2 page table (PD) for this virtual address, in range 0..512

pub fn p3_index(self) -> PageTableIndex

Returns the index into the P3 page table (PDPT) for this virtual address, in range 0..512

pub fn p4_index(self) -> PageTableIndex

Returns the index into the P4 page table (PML4) for this virtual address, in range 0..512