#[repr(transparent)]pub struct VirtAddr(u64);Expand description
A type representing virtual addresses in the CPU’s virtual address space
Tuple Fields
0: u64Implementations
Sourceimpl VirtAddr
impl VirtAddr
Sourcepub fn from_ptr<T>(ptr: *const T) -> Self
pub fn from_ptr<T>(ptr: *const T) -> Self
Creates a new VirtAddr from a *const T or *mut T pointer
Sourcepub fn as_mut_ptr<T>(self) -> *mut T
pub fn as_mut_ptr<T>(self) -> *mut T
Returns the address as a *mut T pointer
Sourcepub fn align_up(self, align: u64) -> Self
pub fn align_up(self, align: u64) -> Self
Returns a new address aligned to the next larger address which is aligned to align
Panics
In debug builds if align is not a power of two
Sourcepub fn align_down(self, align: u64) -> Self
pub fn align_down(self, align: u64) -> Self
Returns a new address aligned to the next smaller address which is aligned to align
Panics
In debug builds if align is not a power of two
Sourcepub fn is_aligned(self, align: u64) -> bool
pub fn is_aligned(self, align: u64) -> bool
Check whether the address is aligned to align
Sourceimpl VirtAddr
impl VirtAddr
Sourcepub fn p1_index(self) -> PageTableIndex
pub fn p1_index(self) -> PageTableIndex
Returns the index into the P1 page table (PT) for this virtual address, in range 0..512
Sourcepub fn p2_index(self) -> PageTableIndex
pub fn p2_index(self) -> PageTableIndex
Returns the index into the P2 page table (PD) for this virtual address, in range 0..512